@@ -49,7 +49,6 @@
 #include <html/HTMLSourceElement.h>
 #include <xml/dom_textimpl.h>
 #include <xml/dom_nodeimpl.h>
-#include <misc/htmlhashes.h>
 #include <html/htmltokenizer.h>
 #include <khtmlview.h>
 #include <khtml_part.h>
@@ -469,6 +468,9 @@ bool KHTMLParser::insertNode(NodeImpl *n, bool flat)
                 return insertNode(n);
             }
             break;
+        case ID_TITLE:
+            popBlock(current->id());
+            return insertNode(n);
         default:
             break;
         }
