@@ -122,6 +122,7 @@ m_marquee( 0 )
     }
     m_buffer[0] = 0;
     m_buffer[1] = 0;
+    m_wasStackingContext = object->style() ? isStackingContext() : false;
 }
 
 RenderLayer::~RenderLayer()
@@ -912,18 +913,25 @@ void RenderLayer::checkScrollbarsAfterLayout()
 
     bool haveHorizontalBar = m_hBar && m_hBar->isEnabled();
     bool haveVerticalBar = m_vBar && m_vBar->isEnabled();
-    
+
     bool hasOvf = m_object->hasOverflowClip();
 
     // overflow:scroll should just enable/disable.
-    if (hasOvf && m_object->style()->overflowX() == OSCROLL)
+    if (m_hBar && hasOvf && m_object->style()->overflowX() == OSCROLL)
         m_hBar->setEnabled(needHorizontalBar);
-    if (hasOvf && m_object->style()->overflowY() == OSCROLL)
+    if (m_vBar && hasOvf && m_object->style()->overflowY() == OSCROLL)
         m_vBar->setEnabled(needVerticalBar);
 
+    // Sometimes we originally had a scrolling overflow, but it got changed to 
+    // hidden/visible. 
+    bool deadScrollX = m_hBar && !m_object->scrollsOverflowX();
+    bool deadScrollY = m_vBar && !m_object->scrollsOverflowY();
+
     // overflow:auto may need to lay out again if scrollbars got added/removed.
+    // Also remove now useless scrollbars for non-scrollable overflows
     bool scrollbarsChanged = (hasOvf && m_object->style()->overflowX() == OAUTO && haveHorizontalBar != needHorizontalBar)
-                          || (hasOvf && m_object->style()->overflowY() == OAUTO && haveVerticalBar != needVerticalBar);
+                          || (hasOvf && m_object->style()->overflowY() == OAUTO && haveVerticalBar != needVerticalBar)
+                          || deadScrollX || deadScrollY;
     if (scrollbarsChanged && !m_inScrollbarRelayout) {
         if (m_object->style()->overflowX() == OAUTO) {
             showScrollbar(Qt::Horizontal, needHorizontalBar);
@@ -939,6 +947,16 @@ void RenderLayer::checkScrollbarsAfterLayout()
             else
                 resetYOffset();
         }
+        
+        if (deadScrollX) {
+            showScrollbar(Qt::Horizontal, false);
+            resetXOffset();
+        }
+            
+        if (deadScrollY) {
+            showScrollbar(Qt::Vertical, false);
+            resetYOffset();
+        }
 
         m_object->setNeedsLayout(true);
         m_inScrollbarRelayout = true;
@@ -949,7 +967,7 @@ void RenderLayer::checkScrollbarsAfterLayout()
         m_inScrollbarRelayout = false;
 	return;
     }
-
+    
     m_inScrollbarRelayout = false;
 
     // Set up the range (and page step/line step).
@@ -1680,25 +1698,35 @@ bool RenderLayer::shouldBeOverflowOnly() const
 
 void RenderLayer::styleChanged()
 {
+    RenderLayer* parentSC = stackingContext();
+
     // If we stopped being a stacking context, make sure to clear our
     // child lists so we don't end up with dangling references when a kid
     // is removed (as it wouldn't know to remove from us)
-    if (!isStackingContext() && (m_posZOrderList || m_negZOrderList)) {
+    bool nowStackingContext = isStackingContext();
+    if (!nowStackingContext && (m_posZOrderList || m_negZOrderList)) {
         delete m_posZOrderList;
         m_posZOrderList = 0;
         delete m_negZOrderList;
         m_negZOrderList = 0;
     }
 
+    // If we stopped or started being a stacking context, dirty the parent, as
+    // who is responsible for some of the layers may change
+    if (nowStackingContext != m_wasStackingContext && parentSC) {
+        parentSC->dirtyZOrderLists();
+    }
+
+    m_wasStackingContext = nowStackingContext;
+
     bool isOverflowOnly = shouldBeOverflowOnly();
     if (isOverflowOnly != m_isOverflowOnly) {
         m_isOverflowOnly = isOverflowOnly;
         RenderLayer* p = parent();
-        RenderLayer* sc = stackingContext();
         if (p)
             p->dirtyOverflowList();
-        if (sc)
-            sc->dirtyZOrderLists();
+        if (parentSC)
+            parentSC->dirtyZOrderLists();
     }
 
     if (m_object->hasOverflowClip() && 
@@ -2009,3 +2037,4 @@ void Marquee::timerEvent(QTimerEvent* /*evt*/)
 }
 
 #include "render_layer.moc"
+// kate: indent-width 4; replace-tabs on; tab-width 8; space-indent on;
