@@ -34,9 +34,11 @@
 #include <kstandarddirs.h>
 #include <kpixmapsequence.h>
 #include <kpixmapsequencewidget.h>
+#include <krun.h>
 
 #include <kdebug.h>
 #include <kconfiggroup.h>
+#include <kservice.h>
 
 using namespace KNS3;
 
@@ -110,6 +112,8 @@ bool UploadDialog::Private::init(const QString& configfile)
     q->connect(ui.providerComboBox, SIGNAL(currentIndexChanged(QString)), q, SLOT(_k_providerChanged(QString)));
     q->connect(ui.radioUpdate, SIGNAL(toggled(bool)), q, SLOT(_k_updateContentsToggled(bool)));
 
+    q->connect(ui.registerNewAccountLabel, SIGNAL(linkActivated(QString)), q, SLOT(_k_openRegisterAccountWebpage(QString)));
+
     //Busy widget
     busyWidget = new KPixmapSequenceWidget();
     busyWidget->setSequence(KPixmapSequence("process-working", 22));
@@ -251,6 +255,13 @@ void UploadDialog::Private::_k_providersLoaded(const QStringList& providers)
 void UploadDialog::Private::_k_providerChanged(const QString& providerName)
 {
     atticaHelper->setCurrentProvider(providerName);
+    QString registerUrl = atticaHelper->provider().getRegisterAccountUrl();
+    if ( ! registerUrl.isEmpty() ) {
+        ui.registerNewAccountLabel->setText("<a href=\"register\">" + i18n("Register a new account") + "</a>");
+    }
+    else {
+        ui.registerNewAccountLabel->setText(QString());
+    }
     ui.username->clear();
     ui.password->clear();
     QString user;
@@ -696,6 +707,10 @@ void UploadDialog::Private::_k_contentAdded(Attica::BaseJob* baseJob)
     }
 }
 
+void UploadDialog::Private::_k_openRegisterAccountWebpage(QString) {
+    KRun::runUrl(atticaHelper->provider().getRegisterAccountUrl(), "text/html", q);
+}
+
 void UploadDialog::Private::doUpload(const QString& index, const KUrl& path)
 {
     QFile file(path.toLocalFile());
